pub(super) struct FCJob<'job> {
    pub(super) db: &'job DB,
    pub(super) db_state_guard: RwLockReadGuard<'job, DbState>,
    pub(super) dangling_nodes: &'job mut DanglingNodeSetsDeque,
}
A struct that contains references that are used over the course of one run of flushing+compaction.

This type is necessary iff the run makes 1+ const references and 1+ mut references to fields within struct FlushingAndCompactionWorker.

Fields

db: &'job DBdb_state_guard: RwLockReadGuard<'job, DbState>dangling_nodes: &'job mut DanglingNodeSetsDeque

Implementations

source

impl<'job> FCJob<'job>

source

pub(super) fn do_flush_and_compact<'data>( &self, units: Vec<&'data CommittedUnit>, skip_tombstones: bool ) -> Result<CompactionResult>

source

fn should_slice_be_compacted<'data>(units: &[&'data CommittedUnit]) -> bool

A given slice of Units should be compacted iff any of:

  • The slice contains 1+ MemLogs.
  • The slice contains 2+ Units (regardless of MemLogs or SSTables).

This is an arbitrary policy, and can be tuned in the future.

source

fn potentially_create_compacted_unit<'data>( &self, existing_units: &[&'data CommittedUnit], skip_tombstones: bool ) -> Result<Option<CompactedUnit>>

source

fn derive_kmerged_iter<'data, K, V>( entrysets: impl Iterator<Item = &'data CommittedEntrySet<K, OptDatum<V>>>, skip_tombstones: bool ) -> impl Iterator<Item = Entry<'data, K, OptDatum<V>>>
where K: 'data + Deser + Ord, OptDatum<V>: 'data + Deser,

source

fn derive_commit_info<'data>(units: &[&'data CommittedUnit]) -> CommitInfo

source

impl<'job> FCJob<'job>